Chat
=============================

.. currentmodule:: alfred3_interact.element

.. autoclass:: Chat
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:




      ~Chat.add_css


      ~Chat.add_js


      ~Chat.added_to_experiment


      ~Chat.added_to_page


      ~Chat.prepare_web_widget


      ~Chat.render_inner_html







   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~Chat.base_template
         ~Chat.converted_width
         ~Chat.css_class_container
         ~Chat.css_class_element
         ~Chat.css_code
         ~Chat.css_urls
         ~Chat.display_standalone
         ~Chat.element_template
         ~Chat.element_width
         ~Chat.exp
         ~Chat.experiment
         ~Chat.font_size
         ~Chat.js_code
         ~Chat.js_template
         ~Chat.js_urls
         ~Chat.name
         ~Chat.page
         ~Chat.position
         ~Chat.section
         ~Chat.short_tree
         ~Chat.should_be_shown
         ~Chat.showif
         ~Chat.template_data
         ~Chat.tree
         ~Chat.web_widget
         ~Chat.width
         ~Chat.align
         ~Chat.height
         ~Chat.instance_log
         ~Chat.log
